==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicPopupMenuUI__24TopWindowListener.h <==
// class javax.swing.plaf.basic.BasicPopupMenuUI$TopWindowListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d4533d352b89ae77 javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener_H_
#define _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object;
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_refs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$refs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vmethods	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtable	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$_init$84d44dbc97f08e44(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$_init$946abcd8bf8c5c85(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$componentHidden$c45a3d9480cd8f67(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$componentMoved$81a358183048de7c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$componentShown$f9db658060a8b292(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method_info$componentHidden$c45a3d9480cd8f67;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method_info$componentMoved$81a358183048de7c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method_info$componentResized$ac5fcd90b88c07ec;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method_info$componentShown$f9db658060a8b292;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vmethods {
	void	(*componentHidden$c45a3d9480cd8f67)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentMoved$81a358183048de7c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentShown$f9db658060a8b292)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vmethods	javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$refs {
    _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_refs	javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_nonrefs	javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object {
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicPopupMenuUI__24TopWindowListener.h <==
// class javax.swing.plaf.basic.BasicPopupMenuUI$TopWindowListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c4f9557c6cbeb1d1 javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener_H_
#define _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object;
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_refs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$refs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vmethods	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtable	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$_init$84d44dbc97f08e44(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$_init$946abcd8bf8c5c85(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$componentHidden$c45a3d9480cd8f67(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$componentMoved$81a358183048de7c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method$componentShown$f9db658060a8b292(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method_info$componentHidden$c45a3d9480cd8f67;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method_info$componentMoved$81a358183048de7c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method_info$componentResized$ac5fcd90b88c07ec;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$method_info$componentShown$f9db658060a8b292;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vmethods {
	void	(*componentHidden$c45a3d9480cd8f67)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentMoved$81a358183048de7c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentShown$f9db658060a8b292)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vmethods	javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$refs {
    _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_refs	javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$sub_nonrefs	javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$object {
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$vtype _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPopupMenuUI__24TopWindowListener_H_ */
